export declare enum EFieldTypes {
    TEXT = "text",
    NUMBER = "number",
    SWITCH = "switch",
    DATE = "date",
    DATE_RANGE = "dateRange",
    AUTOCOMPLETE = "autoComplete",
    FILE = "file",
    ARRAY = "array",
    MOBILE_PHONE = "mobilePhone",
    MULTIPLE_AUTOCOMPLETE = "autoCompleteMultiple",
    RADIOBUTTON = "radioButton",
    YES_NO_RADIOBUTTON = "yesNoRadioButton",
    EMPTY = "empty",
    CHECKBOX = "checkbox",
    RADIOBUTTON_MATRIX = "radioButtonMatrix",
    ASSESSMENT = "assessment"
}
export type GridSize = 1 | 2 | 3 | 4 | 6 | 8 | 10 | 12 | 'auto';
export interface IRegularBreakpoints {
    lg?: GridSize;
    md?: GridSize;
    sm?: GridSize;
    xl?: GridSize;
    xs?: GridSize;
}
export interface IOption<T> {
    id: number;
    label: string;
    value: T;
}
export declare enum ESelectTypes {
    COUNTRIES = "countries",
    RELATIONSHIP = "relationship"
}
export interface IFormFieldBase {
    type: EFieldTypes;
    fieldName: string;
    initialValue?: any;
    templateId?: string;
}
export interface IFormGroupBase {
    title?: string;
    subtitle?: string;
    children: Array<IFormFieldBase>;
}
export type ICrossFieldConditionsParams = {
    required?: string;
    disabled?: string;
    renderCondition?: string;
    disabledCondition?: string;
};
export interface ICrossFieldValidationRule {
    errorKey: string;
    testCondition: string;
    meta?: {
        param: number;
    };
}
export interface IFormSettingsOverrides {
    disablePast?: boolean;
    disableFuture?: boolean;
    disabled?: boolean;
    backendSelectType?: ESelectTypes;
    fieldTitle?: string;
    fieldSubtitle?: string | null;
    initialValue?: any;
    options?: IOption<any>[];
    placeholder?: string;
    helperText?: string;
    label?: string;
}
export type ICrossFieldValidations = {
    [key in string]?: ICrossFieldValidationRule[];
};
export type IJsonSchemaProperty = {
    id: number;
    type: 'string' | 'boolean' | 'array' | 'number';
    nullable?: boolean;
    maxLength?: number;
    minLength?: number;
    min?: string;
    max?: string;
    pattern?: string;
    oneOf?: Array<string | boolean | null>;
    items?: {
        type: 'string';
        format: 'date';
        minLength: number;
        required: boolean;
    };
};
export type IProperty = {
    [key in string]: IJsonSchemaProperty;
};
export interface IJsonSchema {
    $schema: string;
    title: string;
    description: string;
    type: string;
    properties: IProperty;
    required: Array<string>;
}
export interface IValidationError {
    translationKey: string;
    fallbackLanguageTranslation: string;
    meta: {
        [key: string]: any;
    };
}
export interface IValidationErrorField {
    property: string;
    constraints: {
        [key: string]: IValidationError;
    };
}
export type IValidationErrors = {
    [key in string]?: IValidationErrorField;
};
