import {
  createErrorObject,
  flattenValues,
  formatYupValidationErrors,
  functionFromString,
  getAllFieldNames,
  getErrorMessages,
  isFormGroup,
  parseForm,
  valuesToDBFormat,
} from './helpers';
import {
  IChildrenArrayFull,
  IChildrenAssessmentFull,
  IChildrenAutoCompleteFull,
  IChildrenCheckboxFull,
  IChildrenDateFull,
  IChildrenDateRangeFull,
  IChildrenEmptyFull,
  IChildrenFileFull,
  IChildrenMobilePhoneFull,
  IChildrenMultipleAutocompleteFull,
  IChildrenNumberFull,
  IChildrenRadioButtonFull,
  IChildrenRadioButtonMatrixFull,
  IChildrenSwitchFull,
  IChildrenTextFull,
  IChildrenYesNoRadioButtonFull,
  ICommonChildrenFull,
  IFormFieldFull,
  IFormGroupFull,
  IRadioButtonMatrixOptions,
} from './inputsModels';

import {
  IAllForms,
  ICrossFieldConditions,
  IFormLayout,
  IFormOverrides,
  IFormV1,
  IFormV2,
  IFormV2Full,
} from './models';
import {
  EFieldTypes,
  ESelectTypes,
  GridSize,
  ICrossFieldValidationRule,
  ICrossFieldValidations,
  IFormFieldBase,
  IFormGroupBase,
  IFormSettingsOverrides,
  IJsonSchema,
  IJsonSchemaProperty,
  IOption,
  IRegularBreakpoints,
  IValidationError,
  IValidationErrorField,
} from './modelsCommon';
import { IFormParsed, IFormParsedFull, IFormSetting, IFormSettings } from './modelsParsed';

import {
  buildYupSchema,
  getFieldError,
  getInitialValues,
  getRuleValueFromSchema,
  makeCrossFieldValidation,
  validateValues,
} from './utils';
import { parseToFormV2 } from './utilsV2';
import { FormV2Full, validateSchema } from './validate';

export type {
  IOption,
  IFormFieldBase,
  IFormGroupBase,
  IFormV1,
  IFormV2,
  IFormParsed,
  IValidationErrorField,
  IValidationError,
  IRegularBreakpoints,
  IAllForms,
  IFormSetting,
  IFormSettings,
  IJsonSchema,
  IJsonSchemaProperty,
  IFormGroupFull,
  IFormFieldFull,
  IChildrenTextFull,
  IChildrenAutoCompleteFull,
  IChildrenDateFull,
  IChildrenMobilePhoneFull,
  IChildrenRadioButtonFull,
  IChildrenYesNoRadioButtonFull,
  IChildrenCheckboxFull,
  IChildrenNumberFull,
  IChildrenDateRangeFull,
  IChildrenFileFull,
  IChildrenMultipleAutocompleteFull,
  IChildrenRadioButtonMatrixFull,
  IRadioButtonMatrixOptions,
  IChildrenEmptyFull,
  IChildrenSwitchFull,
  IChildrenArrayFull,
  IChildrenAssessmentFull,
  ICommonChildrenFull,
  IFormParsedFull,
  IFormV2Full,
  ICrossFieldConditions,
  IFormLayout,
  IFormOverrides,
  GridSize,
  ICrossFieldValidations,
  ICrossFieldValidationRule,
  IFormSettingsOverrides,
};

export {
  EFieldTypes,
  ESelectTypes,
  FormV2Full,
  parseToFormV2,
  flattenValues,
  validateValues,
  buildYupSchema,
  makeCrossFieldValidation,
  getInitialValues,
  getRuleValueFromSchema,
  getFieldError,
  isFormGroup,
  functionFromString,
  getErrorMessages,
  formatYupValidationErrors,
  createErrorObject,
  parseForm,
  getAllFieldNames,
  valuesToDBFormat,
  validateSchema,
};
