import {
  EFieldTypes,
  ESelectTypes,
  IFormGroupBase,
  IOption,
  IRegularBreakpoints,
} from './modelsCommon';

export interface IRadioButtonMatrixOptions {
  rows: IOption<any>[];
  columns: IOption<any>[];
  grid?: IRegularBreakpoints;
}

export interface ICommonChildrenFull {
  type: EFieldTypes;
  fieldName: string;
  templateId: string;
  disabled?: boolean;
  initialValue: string | null | boolean | number | [null, null] | false;
  fieldTitle?: string;
  fieldSubtitle?: string;
  label?: string;
}

export interface IChildrenTextFull extends ICommonChildrenFull {
  type: EFieldTypes.TEXT;
  initialValue: null;
  multiline?: boolean;
  maxLength?: string;
  placeholder?: string;
}

export interface IChildrenAutoCompleteFull extends ICommonChildrenFull {
  placeholder?: string;
  type: EFieldTypes.AUTOCOMPLETE;
  initialValue: null;
  backendOptions?: boolean;
  backendSelectType?: ESelectTypes;
  options: IOption<string>[];
  disabledOptionIds?: number[];
}

export interface IChildrenMobilePhoneFull extends ICommonChildrenFull {
  placeholder?: string;
  type: EFieldTypes.MOBILE_PHONE;
  initialValue: string;
  maxLength?: string;
}

export interface IChildrenRadioButtonFull extends ICommonChildrenFull {
  type: EFieldTypes.RADIOBUTTON;
  initialValue: null;
  options: IOption<string>[];
  placeholder?: string;
}

export interface IChildrenYesNoRadioButtonFull extends ICommonChildrenFull {
  type: EFieldTypes.YES_NO_RADIOBUTTON;
  initialValue: null;
  options: IOption<boolean>[];
  placeholder?: string;
}

export interface IChildrenCheckboxFull extends ICommonChildrenFull {
  type: EFieldTypes.CHECKBOX;
  label: string;
  initialValue: boolean;
}

export interface IChildrenNumberFull extends ICommonChildrenFull {
  type: EFieldTypes.NUMBER;
  initialValue: number;
  placeholder?: string;
}

export interface IChildrenDateFull extends ICommonChildrenFull {
  type: EFieldTypes.DATE;
  initialValue: null;
  disableFuture?: boolean;
  disablePast?: boolean;
  minDate?: any;
  helperText: string;
  placeholder?: string;
}

export interface IChildrenDateRangeFull extends ICommonChildrenFull {
  type: EFieldTypes.DATE_RANGE;
  initialValue: [null, null];
  disableFuture?: boolean;
  disablePast?: boolean;
  minDate?: any;
  helperText: string;
}

export interface IChildrenFileFull extends ICommonChildrenFull {
  type: EFieldTypes.FILE;
  placeholder?: string;
}

export interface IChildrenMultipleAutocompleteFull extends ICommonChildrenFull {
  type: EFieldTypes.MULTIPLE_AUTOCOMPLETE;
  // need to implement
}

export interface IChildrenRadioButtonMatrixFull extends ICommonChildrenFull {
  type: EFieldTypes.RADIOBUTTON_MATRIX;
  radioButtonMatrixOptions: IRadioButtonMatrixOptions;
}

export interface IChildrenAssessmentFull extends ICommonChildrenFull {
  type: EFieldTypes.ASSESSMENT;
  assessments: {
    [key: number]: string;
  };
}

export interface IChildrenEmptyFull extends ICommonChildrenFull {
  type: EFieldTypes.EMPTY;
}

export interface IChildrenSwitchFull extends ICommonChildrenFull {
  type: EFieldTypes.SWITCH;
  placeholder?: string;
}

export interface IChildrenArrayFull extends ICommonChildrenFull {
  type: EFieldTypes.ARRAY;
  // need to implement
}

export type IFormFieldFull =
  | IChildrenTextFull
  | IChildrenAutoCompleteFull
  | IChildrenDateFull
  | IChildrenMobilePhoneFull
  | IChildrenRadioButtonFull
  | IChildrenYesNoRadioButtonFull
  | IChildrenCheckboxFull
  | IChildrenNumberFull
  | IChildrenDateRangeFull
  | IChildrenFileFull
  | IChildrenMultipleAutocompleteFull
  | IChildrenRadioButtonMatrixFull
  | IChildrenEmptyFull
  | IChildrenSwitchFull
  | IChildrenArrayFull
  | IChildrenAssessmentFull;

export interface IFormGroupFull extends IFormGroupBase {
  id: string;
  title?: string;
  subtitle?: string;
  children: Array<IFormFieldFull>;
}
