import { IFormFieldFull, IFormGroupFull } from './inputsModels';
import {
  ICrossFieldConditionsParams,
  ICrossFieldValidations,
  IFormFieldBase,
  IFormGroupBase,
  IFormSettingsOverrides,
  IJsonSchema,
  IRegularBreakpoints,
} from './modelsCommon';
import { IFormParsedFull } from './modelsParsed';

interface IValidationObjectV1 extends IJsonSchema {
  crossFieldValidations: ICrossFieldValidations;
}

export interface IFormFieldV1 extends IFormFieldBase {
  grid?: IRegularBreakpoints;
  renderCondition?: string;
  disabledCondition?: string;
}

export interface IFormGroupV1 extends IFormGroupBase {
  children: Array<IFormFieldV1>;
}

export interface IFormV1 {
  formatVersion: 1;
  validationObject: IValidationObjectV1;
  children: Array<IFormFieldV1 | IFormGroupV1>;
  submitButtonText: string;
  cancelButtonText?: string;
}

export type ICrossFieldConditions = {
  [key in string]?: ICrossFieldConditionsParams;
};

export type IFormLayout = {
  [key in string]?: IRegularBreakpoints;
};

export type IFormOverrides = {
  [key in string]?: IFormSettingsOverrides;
};

export interface IFormV2 {
  formatVersion: 2;
  validationObject: IJsonSchema;
  crossFieldValidations: ICrossFieldValidations;
  crossFieldConditions: ICrossFieldConditions;
  overrides: IFormOverrides;
  formLayout: IFormLayout;
  children: Array<IFormFieldBase | IFormGroupBase>;
  submitButtonText: string;
  cancelButtonText?: string;
}

export interface IFormV2Full extends IFormV2 {
  children: Array<IFormFieldFull | IFormGroupFull>;
}

export type IAllForms = IFormV1 | IFormV2 | IFormParsedFull | IFormV2Full;
